Struct fernet::MultiFernet

source ·
pub struct MultiFernet { /* private fields */ }

Implementations

source

impl MultiFernet

MultiFernet encapsulates the encrypt operation with the first Fernet instance and decryption with the Fernet instances provided in order until successful decryption or a DecryptionError.

source

pub fn new(keys: Vec<Fernet>) -> MultiFernet

source

pub fn encrypt(&self, data: &[u8]) -> String

Encrypts data with the first Fernet instance. Returns a value (which is base64-encoded) that can be passed to MultiFernet::decrypt.

source

pub fn decrypt(&self, token: &str) -> Result<Vec<u8>, DecryptionError>

Decrypts a ciphertext, using the Fernet instances provided. Returns either Ok(plaintext) if decryption is successful or Err(DecryptionError) if no decryption was possible across the set of fernet keys.