Struct fernet::MultiFernet
source · pub struct MultiFernet { /* private fields */ }Implementations
sourceimpl MultiFernet
impl MultiFernet
MultiFernet encapsulates the encrypt operation with the first Fernet
instance and decryption with the Fernet instances provided in order
until successful decryption or a DecryptionError.